@@ -33,18 +33,18 @@ package G;
 
 use strict;
 
-# import "prelude" extensions
+# import core extensions
 use SubOpt;
 use Rcmd;
 
 # import messenger
 use G::Messenger;
-
-# import "skyline" extensions
-require G::Skyline;
-require G::DynamicLoader;
 use G::Inspire;
 
+# import core modules
+require G::IO::Handler;
+require G::DynamicLoader;
+
 # import db classes
 use G::DB::SDB;
 use G::DB::BDB;
@@ -106,11 +106,10 @@ use G::System::CHI;
 use G::System::ReL8;
 use G::System::FuncD;
 
-use vars qw($VERSION @ISA @EXPORT);
-
 require Exporter;
 
-@ISA = qw(G::Skyline Exporter);
+our @ISA = qw(G::IO Exporter);
+our @EXPORT;
 
 # export odyssay functions
 push(@EXPORT, @G::Seq::AminoAcid::EXPORT);
@@ -175,7 +174,7 @@ push(@EXPORT, @G::Messenger::EXPORT);
 push(@EXPORT, @G::DynamicLoader::EXPORT);
 
 
-$VERSION = $G::Skyline::VERSION;
+our $VERSION = $G::IO::VERSION;
 
 mkdir($ENV{HOME} . '/.glang/data/');
 
