@@ -141,33 +141,40 @@ sub make_gb {
             }
 	}
 
-        foreach (sort keys(%{$gb->{$feat}})){
-            next if($_ eq "on" || $_ eq "partial" || $_ eq "start" || $_ eq "end" 
-	       || $_ eq "feature" || $_ eq "type" || $_ eq "direction" 
-	       || $_ eq "join" || $_ eq "cds");
+        foreach my $key (sort keys(%{$gb->{$feat}})){
+            next if($key eq "on" || $key eq "partial" || $key eq "start" || $key eq "end" 
+	       || $key eq "feature" || $key eq "type" || $key eq "direction" 
+	       || $key eq "join" || $key eq "cds");
 
-	    my $str = "/".$_."="."\"".$gb->{$feat}->{$_}."\"";
-	    $lng = length($str);
-	    if($lng >= 58 ){
-		if($str =~ /\s/){
-		    my $tmpline = "";
-		    foreach my $word (split(/ /, $str)){
-			if(length($tmpline) + length($word) < 58){
-			    $tmpline .= $word . ' ';
-			}else{
-			    printf OUT "%-20.20s %-58.58s\n",$dummy,$tmpline;
-			    $tmpline = $word . ' ';
-			}
-		    }
-		    printf OUT "%-20.20s %-58.58s\n",$dummy,$tmpline;
-		}else{
-		    for($i = 0;$i < $lng;$i += 58){
-			my $pr = substr($str,$i,58);
-			printf OUT "%-20.20s %-58.58s\n",$dummy,$pr;
-		    }
+	    if($gb->{$feat}->{$key} =~ /\t/){
+		foreach my $multiplekey (split(/\t/, $gb->{$feat}->{$key})){
+		    my $str = "/" . $key . "=" . "\"" . $multiplekey . "\"";
+		    printf OUT "%-20.20s %-58.58s\n","$dummy",$str;
 		}
 	    }else{
-		printf OUT "%-20.20s %-58.58s\n","$dummy",$str;
+		my $str = "/".$key."="."\"".$gb->{$feat}->{$key}."\"";
+		$lng = length($str);
+		if($lng >= 58 ){
+		    if($str =~ /\s/){
+			my $tmpline = "";
+			foreach my $word (split(/ /, $str)){
+			    if(length($tmpline) + length($word) < 58){
+				$tmpline .= $word . ' ';
+			    }else{
+				printf OUT "%-20.20s %-58.58s\n",$dummy,$tmpline;
+				$tmpline = $word . ' ';
+			    }
+			}
+			printf OUT "%-20.20s %-58.58s\n",$dummy,$tmpline;
+		    }else{
+			for($i = 0;$i < $lng;$i += 58){
+			    my $pr = substr($str,$i,58);
+			    printf OUT "%-20.20s %-58.58s\n",$dummy,$pr;
+			}
+		    }
+		}else{
+		    printf OUT "%-20.20s %-58.58s\n","$dummy",$str;
+		}
 	    }
 	}
     }
